@@ -15,5 +15,5 @@ class User(AbstractUser, DjangoSsoAppUserModelMixin):
         verbose_name = _('user')
         verbose_name_plural = _('users')
 
-    def get_absolute_url(self):
+    def get_relative_url(self):
         return reverse("users:detail", kwargs={"username": self.username})
