@@ -32,11 +32,11 @@ class Passepartout(CreatedAtModel, UpdatableModel, DeactivableModel):
     class Meta:
         app_label = 'django_sso_app'
         verbose_name = _('Passepartout')
-        unique_together = ('token', 'deleted')
+        unique_together = ('token', 'is_active')
 
     objects = PassepartoutManager()
 
-    deleted = models.BooleanField(_('deleted'), default=False)
+    # deleted = models.BooleanField(_('deleted'), default=False)
     token = models.CharField(_('token'), unique=True, db_index=True, max_length=36)
     jwt = models.TextField(_('jwt'), null=True, blank=True)
     device = models.ForeignKey(Device, on_delete=models.CASCADE, verbose_name=_('device'))
@@ -48,3 +48,7 @@ class Passepartout(CreatedAtModel, UpdatableModel, DeactivableModel):
 
     def __str__(self):
         return '{0}:{1}'.format(self.id, self.device.fingerprint)
+
+    @property
+    def user(self):
+        return self.device.user
