@@ -5,12 +5,12 @@ from urllib.parse import urlencode
 # import pyximport
 # pyximport.install()
 
-from django.shortcuts import reverse
+from django.urls import reverse
 
 from ...utils import get_session_key, set_session_key
 from ...permissions import is_django_staff
 from ... import app_settings
-from ..devices.utils import get_request_device
+from ..devices.utils import get_or_create_request_device
 
 from .models import Passepartout
 from .functions import get_next_bump
@@ -37,7 +37,7 @@ def get_passepartout_login_redirect_url(request):
             if nextUrl is None:
                 nextUrl = app_settings.APP_URL
 
-            device = get_request_device(request)
+            device = get_or_create_request_device(request)
 
             assert device is not None
 
