@@ -13,7 +13,12 @@ User = get_user_model()
 
 @receiver(post_save, sender=User)
 def create_user_profile(sender, instance, created, **kwargs):
+    """
+    App still creates profile for "staff" users
+    """
     if kwargs['raw']:
+        # setting property flag
+        setattr(instance, '__dssoa__loaddata', True)
         # https://github.com/django/django/commit/18a2fb19074ce6789639b62710c279a711dabf97
         return
 
