@@ -91,6 +91,6 @@ class SubscriptionSerializer(AbsoluteUrlSerializer):
 
     def get_profile(self, instance):
         request = self.context['request']
-        profile_url = instance.profile.get_absolute_rest_url()
+        profile_url = instance.profile.get_relative_rest_url()
 
         return request.build_absolute_uri(profile_url)
