@@ -13,7 +13,6 @@ from django.core.exceptions import SuspiciousOperation
 
 from django_filters.rest_framework import DjangoFilterBackend
 
-from allauth.account.adapter import get_adapter
 from allauth.account.utils import filter_users_by_username, filter_users_by_email
 
 from rest_framework import generics
@@ -32,8 +31,10 @@ from ...apps.emails.models import EmailAddress
 from ...permissions import StaffPermission
 from ...permissions import is_staff, is_django_staff
 from ...utils import invalidate_cookie, get_session_key
+from ..devices.utils import renew_response_jwt
 from ... import app_settings
 from .filters import UserFilter
+from ...views import DjangoSsoAppBaseViewMixin
 
 User = get_user_model()
 
@@ -97,7 +98,8 @@ class UserApiViewSet(mixins.ListModelMixin,
                      mixins.CreateModelMixin,
                      mixins.RetrieveModelMixin,
                      mixins.DestroyModelMixin,
-                     viewsets.GenericViewSet):
+                     viewsets.GenericViewSet,
+                     DjangoSsoAppBaseViewMixin):
     """
     User api viewset
     """
@@ -174,7 +176,6 @@ class UserApiViewSet(mixins.ListModelMixin,
         logger.debug('Partial_update status code is {}, {}'.format(response_status_code, request.data))
 
         if response_status_code == 200:
-            adapter = get_adapter(request)
             requesting_user = request.user
             is_same_user = requesting_user == user
 
@@ -184,7 +185,7 @@ class UserApiViewSet(mixins.ListModelMixin,
                 if get_session_key(request, '__dssoa__user_password_updated', False):
                     invalidate_cookie(response, app_settings.JWT_COOKIE_NAME)
                 else:
-                    adapter.try_update_response_jwt(user, response)
+                    self.update_response_jwt(user, response)
 
         return response
 
