@@ -103,7 +103,7 @@ class DjangoSsoAppApiGatewayAppAuthenticationBackend(DjangoSsoAppAppBaseAuthenti
 
         else:
             if app_settings.REPLICATE_PROFILE:
-                logger.debug('Must replicate profile')
+                logger.debug('Should replicate profile')
 
                 if decoded_jwt is None:
                     logger.warning('decoded_jwt not set')
@@ -164,7 +164,7 @@ class DjangoSsoAppJwtAppAuthenticationBackend(DjangoSsoAppAppBaseAuthenticationB
 
         else:
             if app_settings.REPLICATE_PROFILE:
-                logger.debug('Must replicate profile')
+                logger.debug('Should replicate profile')
 
                 if decoded_jwt is None:
                     logger.warning('decoded_jwt not set')
